# 4. Address issue using CV, CCV pairs only (excluding the CCCV). 
# Here I think we would be able to assign our clusters into three sonority profiles, 
# falling vs. rising vs. level. So demo here would be that in going from CV to CCV 
# sonority profile does not affect the way the intervals change (or do not change). 
# This is exactly like we do now but only on the CV-CCV subset of our data. 
# (& then we also have the CCV-CCCV pairs only were we could do the same). 
library(tidyverse)
library(lme4)
library(plyr)
source("functions/style3.R")

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
    #value[value=="LE2A"] <- "LE-ᴛᴏ-A"
    value[value=="CC2A"] <- "Global timing"# "CC-ᴛᴏ-A"
    value[value=="RE2A"] <- "Local timing" #"RE-ᴛᴏ-A"
    #  value[value=="LE2A"] <- "LE-TO-A"
    # value[value=="CC2A"] <- "CC-TO-A"
    # value[value=="RE2A"] <- "RE-TO-A"
  }
  return(value)
}

results<- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>%
    filter(cluster %in% c("CV", "CCV"),
           interval_type %in% c("CC2A", "RE2A"))
results$interval_type <- factor(results$interval_type, ordered = TRUE, levels = c("CC2A", "RE2A"))
results$cluster <- factor(results$cluster, ordered = TRUE, levels = c("CV", "CCV"))

results$sonority <- 0
results[results$triplet == 1,]$sonority <- 111 
results[results$triplet == 2,]$sonority <- 132
results[results$triplet == 3,]$sonority <- 311
results[results$triplet == 4,]$sonority <- 321  
results[results$triplet == 5,]$sonority <- 123
results[results$triplet == 6,]$sonority <- 412
results[results$triplet == 7,]$sonority <- 112
results[results$triplet == 8,]$sonority <- 134
results[results$triplet == 9,]$sonority <- 213

results$sonority <- as.character(results$sonority)

results[results$cluster == "CV",]$sonority <- substr(results[results$cluster == "CV",]$sonority, start = 3, stop = 3)
results[results$cluster == "CCV",]$sonority <- substr(results[results$cluster == "CCV",]$sonority, start = 2, stop = 2)

results$profile <- NA

for(i in unique(results$triplet)){
  triplet <- results %>% filter(triplet == i)
  CV <- unique(triplet[triplet$cluster == "CV",]$sonority)
  CCV <- unique(triplet[triplet$cluster == "CCV",]$sonority)

  CCV_CV <- ifelse(CCV > CV, "falling",
                   ifelse(CCV < CV, "rising", 
                          ifelse(CCV == CV, "level", NA)))
  
  results[results$triplet == i ,]$profile <- CCV_CV
}

table(results$profile, results$cluster)


plot <- ggplot(data = results, aes(x = cluster, y = froP_V )) +
  geom_boxplot() 
plot <- plot + facet_grid(profile ~ interval_type, labeller = i_labeller)
plot <- style(plot);plot

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/cvccvson.pdf", family="Times", bg = "transparent", width = 5, height = 4)
plot
dev.off()


# Individual cluster size differences for interval type and sonority profile
#results$LE_FAll <- ifelse(results$cond == "a" & results$profile == "falling", -1, ifelse(results$cond == "b" & results$profile == "falling", 1, 0))
results$CC_FAll <- ifelse(results$cond == "d" & results$profile == "falling", -1, ifelse(results$cond == "e" & results$profile == "falling", 1, 0))
results$RE_FAll <- ifelse(results$cond == "g" & results$profile == "falling", -1, ifelse(results$cond == "h" & results$profile == "falling", 1, 0))

#results$LE_LEVEL <- ifelse(results$cond == "a" & results$profile == "level", -1, ifelse(results$cond == "b" & results$profile == "level", 1, 0))
results$CC_LEVEL <- ifelse(results$cond == "d" & results$profile == "level", -1, ifelse(results$cond == "e" & results$profile == "level", 1, 0))
results$RE_LEVEL <- ifelse(results$cond == "g" & results$profile == "level", -1, ifelse(results$cond == "h" & results$profile == "level", 1, 0))

#results$LE_RISE <- ifelse(results$cond == "a" & results$profile == "rising", -1, ifelse(results$cond == "b" & results$profile == "rising", 1, 0))
results$CC_RISE <- ifelse(results$cond == "d" & results$profile == "rising", -1, ifelse(results$cond == "e" & results$profile == "rising", 1, 0))
results$RE_RISE <- ifelse(results$cond == "g" & results$profile == "rising", -1, ifelse(results$cond == "h" & results$profile == "rising", 1, 0))


tvals <- data.frame(row.names = 1:6)
tvals$interval <- rep(c("CC2A", "RE2A"), each = 3)
tvals$profile <- rep(c("falling", "level", "rising"), 2)

tvals$contrast <- "CCV-CV"
results$triplet <- as.factor(results$triplet)

m1 <- lmer(log(froP_V) ~ CC_FAll + RE_FAll +
             CC_LEVEL + RE_LEVEL +
             CC_RISE + RE_RISE +
              interval_type + profile
             + (1 + cluster + interval_type | subject)
             + (1 + interval_type | word:repl), REML = FALSE,
             data = results)

tvalsDf <- as.data.frame(summary(m1)$coef)
tvalsDf$fixed <- rownames(tvalsDf)
rownames(tvalsDf) <- NULL
tvalsDf$Estimate <- NULL
tvalsDf$`Std. Error` <- NULL
tvalsDf$df <- NULL
tvalsDf$`Pr(>|t|)` <- NULL
colnames(tvalsDf) <- c("tvals", "fixed")
tvalsDf <- tvalsDf[-c(1,8,9,10),]

tvalsDf <- tvalsDf %>% separate(fixed, into = c("interval", "profile"), sep=  "_")
tvalsDf$interval <- rep(c( "CC2A", "RE2A"),3)
tvalsDf$profile <- rep(c("falling", "level", "rising"), each = 2)

#tvalsDf$sonority <- as.factor(tvalsDf$sonority)
tvalsDf$interval <- as.factor(tvalsDf$interval)
tvalsDf$interval <- factor(tvalsDf$interval, levels(tvalsDf$interval)[c(2,1,3)])


# Plot t-value and p-value for each contrast per triplet
#plot <- ggplot(data = tvalsDf, aes(x = profile, y = tvals, group = interval, linetype = interval)) + geom_point() + geom_line()
plot <- ggplot(data = tvalsDf, aes(x = interval, y = tvals, 
                                   group = profile, linetype = profile)) + geom_point() + geom_line()

none <- element_blank()
plot <- plot + xlab("")
plot <- plot + ylab("t-value")
plot <- plot + theme_bw()
#plot <- plot + facet_wrap(~triplet, ncol = 3)#, labeller = i_labeller

plot <- plot + geom_hline(yintercept = 2, linetype = "dotdash", color = "darkgrey")
plot <- plot + theme(panel.grid.major = none)
plot <- plot + theme(panel.grid.minor = none)

plot <- plot + scale_x_discrete(name ="", 
                        breaks = c("CC2A", "RE2A"),
                        labels = c("Global timing", "Local timing" 
                                   ))

plot <- plot + scale_linetype_discrete(name = "Sonority profile:")

(plot <- plot + theme(
  legend.background = element_rect(colour = NA, fill="transparent"), 
  legend.position = "top", 
  legend.title = element_text(size = 10),
  legend.text = element_text(size = 10)))
plot <- plot + theme(legend.key = none) +  theme(legend.key.height=unit(.25,"line"))

plot <- plot + scale_y_continuous(breaks=seq(0, 8, 2))
plot <- plot + theme(
  axis.text.y =element_text(size=10),
  axis.text.x =element_text(size=10),
  axis.ticks.x = none,
  axis.title=element_text(vjust=0.8))
plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                     plot.background = element_rect(fill = "transparent",colour = NA))
plot
cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/tvalsCVCCV.pdf", family="Times", bg = "transparent", width = 4, height = 3)
plot
dev.off()







