library(tidyverse)
library(lme4)
source("functions/style2.R")

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
    value[value=="CC2A"] <- "Global timing"
    value[value=="RE2A"] <- "Local timing"
  }
  return(value)
}

results <- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>% filter(interval_type != "LE2A")
results$interval_type <- factor(results$interval_type, ordered = TRUE, levels = c("CC2A", "RE2A"))

results$sonority <- 0
results[results$triplet == 1,]$sonority <- 111 
results[results$triplet == 2,]$sonority <- 132
results[results$triplet == 3,]$sonority <- 311
results[results$triplet == 4,]$sonority <- 321  
results[results$triplet == 5,]$sonority <- 123
results[results$triplet == 6,]$sonority <- 412
results[results$triplet == 7,]$sonority <- 112
results[results$triplet == 8,]$sonority <- 134
results[results$triplet == 9,]$sonority <- 213
results$sonority <- as.factor(results$sonority)

results <- filter(results, sonority %in% c(123,321))
results$sonority <- ifelse(results$sonority %in% c(321), "falling", 
                           ifelse(results$sonority %in% c(123), "rising", NA))

results$cluster <- factor(results$cluster, ordered = TRUE, levels = c("CV", "CCV", "CCCV"))
results$sonority <- factor(results$sonority, ordered = TRUE, levels = c("rising", "falling"))


plot <- ggplot(data = results, aes(x = cluster, y = froP_V )) +
  geom_boxplot()
plot <- plot + facet_grid(sonority~interval_type, labeller = i_labeller)
plot <- plot + xlab("")
plot <- plot + ylab("Interval duration (ms)")
plot <- style(plot);plot

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/risefall.pdf", family="Times", bg = "transparent", width = 5, height = 3)
plot
dev.off()

results$interval_type <- factor(results$interval_type, levels = c( "RE2A", "CC2A"))
results$cluster <- factor(results$cluster, levels = c("CCCV", "CV", "CCV"))

contrasts(results$cluster) <- contr.sum(3)
colnames(contrasts(results$cluster)) <- c("CCCV-CCV", "CV-CCV")
rownames(contrasts(results$cluster)) <- c("CCCV", "CV", "CCV")

contrasts(results$interval_type) <- contr.sum(2)
colnames(contrasts(results$interval_type)) <- c( "LOC-GLOB")
rownames(contrasts(results$interval_type)) <- c("LOC","GLOB")

results$sonority <- factor(results$sonority)
results$sonority <- factor(results$sonority, levels = c("rising", "falling"))


#results$LE_CvsCCV <- ifelse(results$cond == "a", -1, ifelse(results$cond == "b", 1, 0))
#results$LE_CCvsCCCV <- ifelse(results$cond == "b", -1, ifelse(results$cond == "c", 1, 0))

results$CC_CvsCCV <- ifelse(results$cond == "d", -1, ifelse(results$cond == "e", 1, 0))
results$CC_CCvsCCCV <- ifelse(results$cond == "e", -1, ifelse(results$cond == "f", 1, 0))

results$RE_CvsCCV <- ifelse(results$cond == "g", -1, ifelse(results$cond == "h", 1, 0))
results$RE_CCvsCCCV <- ifelse(results$cond == "h", -1, ifelse(results$cond == "i", 1, 0))

tvals <- data.frame(row.names = 1:4)
tvals$interval <- rep(c("GLOB", "LOC"),each = 2)
tvals$contrast <- rep(c("CCV-CV", "CCCV-CCV"), 2)

for( tr in levels(results$sonority)){
  m1 <- lmer(log(froP_V) ~ 
               CC_CvsCCV + CC_CCvsCCCV + 
               RE_CvsCCV + RE_CCvsCCCV + 
               interval_type
             + (1 + cluster + interval_type | subject)
             + (1 + interval_type | word:repl), REML = FALSE,
             data = subset(results, sonority == tr))
  
  tvals <- cbind(tvals, summary(m1)$coef[2:5,3])
  names(tvals)[ncol(tvals)] <- tr
}

tvalsDf <- tvals %>% gather("sonority", "tvals", -contrast, -interval)

ipa <- c('\u{0283}', '\u{0292}')

sh<- paste(ipa[1],"a~m", sep = "")
sh1 <- paste(ipa[1],"a~km", sep = "")
sh2 <- paste(ipa[1], "a", sep="")

sh<- paste(sh,sh1,sep ="")
sh<- paste(sh,sh2,sep="")

dg <- paste(ipa[2],"bna",sep="")
dg<-paste("na~bna~",dg, sep="")

tvalsDf$sonority <- as.factor(tvalsDf$sonority)
tvalsDf$interval <- as.factor(tvalsDf$interval)
tvalsDf$contrast <- factor(tvalsDf$contrast, ordered = TRUE, levels = c("CCV-CV", "CCCV-CCV"))
tvalsDf$sonority <- factor(tvalsDf$sonority, ordered = TRUE, levels = c("rising", "falling"))


# Plot t-value and p-value for each contrast per triplet
plot <- ggplot(data = tvalsDf, aes(x = contrast, y = tvals, group = interval, shape = interval)) + geom_point() 
none <- element_blank()
plot <- plot + xlab("")
plot <- plot + ylab("t-value")
plot <- plot + theme_bw()
plot <- plot + facet_grid(~sonority)#, labeller = i_labeller
plot <- plot + geom_hline(yintercept = 2, linetype = "dotdash", color = "darkgrey")
plot <- plot + theme(panel.grid.major = none)
plot <- plot + theme(panel.grid.minor = none)

plot <- plot + scale_shape_manual(values=c(1, 19), 
                                  name = "Interval type",
                                  breaks = c("GLOB", "LOC"),
                                  labels = c("Global timing", 
                                             "Local timing"))


(plot <- plot + theme(
  legend.background = element_rect(colour = NA, fill="transparent"), 
  legend.position = "top", 
  legend.title = element_text(size = 10)))
plot <- plot + theme(legend.key = none) +  theme(legend.key.height=unit(1,"line"))

plot <- plot + scale_y_continuous(breaks=seq(0, 12, 2))
plot <- plot + theme(
  axis.text.y =element_text(size=8),
  axis.text.x =element_text(size=8),
  axis.ticks.x = none,
  axis.title=element_text(vjust=0.8, size = 9),
  strip.text.x = element_text(face="bold", size = 9),
  #  strip.text.y = element_text(face="bold", size = 9, angle = 360),
  strip.background = element_rect( fill = "transparent"))
plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                     plot.background = element_rect(fill = "transparent",colour = NA)); plot

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/risefallres.pdf", family="Times", bg = "transparent", width = 5, height = 3)
plot
dev.off()



