# ----------------
# Descriptives
# ----------------
library(plyr)
library(tidyverse)
library(xtable)

results<- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>%
# Remove a few columns to make this easier understandable
  select(file, subject, interval_type, cluster, triplet, repl, AccOff_V) %>%
  filter(subject %in% c(1:4), # which subjects
         cluster %in% c("CV", "CCV"), # which clusters
         interval_type != "LE2A"
  ) 
# Descriptive data Accustic offset
# Take median across repititions
data.median <- results %>% group_by(triplet, interval_type, cluster, subject) %>%
  dplyr::summarise(
    median = median(AccOff_V)
  ) %>% ungroup()


# SDs across repetiions and clusters
data.sds <- results %>% group_by(triplet, interval_type, subject) %>%
  dplyr::summarise(
    sd = sd(AccOff_V)
  ) %>% ungroup()


# Calculate means and rsds across cluster size
data.rsd <- data.median %>% group_by(triplet, interval_type, subject) %>%
  dplyr::summarise(
    mean = mean(median)
  ) %>%
  right_join(data.sds) %>%
  # calculate rsd from mean sd across cluster size
  mutate(
    rsd = (sd*100)/mean
  ) %>% 
  # Order by subject
  arrange(subject) %>%
  ungroup()


# For summary purposes get the mean of the means, sd and rsds 
# resulting from the previous by-subject statistics
data.mean <- data.rsd %>% group_by(triplet, interval_type) %>%
  dplyr::summarise(
    mean = mean (mean),
    SD = mean (sd),
    RSD = mean (rsd)) %>% ungroup()

RE2A <- data.mean %>% filter(interval_type == "RE2A") %>% select(-interval_type, -triplet)
CC2A <- data.mean %>% filter(interval_type == "CC2A") %>% select(-interval_type, -triplet)

colnames(CC2A) <- c("mean", "SD", "RSD")
colnames(RE2A) <- c("mean", "SD", "RSD")

acc <- cbind(1:9, CC2A, RE2A)
colnames(acc)[1] <- "Triplet"
acc <- round(acc,2)

acc$Triplet <- as.factor(acc$Triplet)
acc$Triplet <- revalue(acc$Triplet, c("1"= "\\textipa{ba$\\sim$dba$\\sim$kdba}", 
                                            "2"= "\\textipa{Sa$\\sim$mSa$\\sim$kmSa}",
                                            "3"="\\textipa{ga$\\sim$bga$\\sim$nbga}", 
                                            "4"="\\textipa{ka$\\sim$ska$\\sim$mska}",
                                            "5"="\\textipa{ma$\\sim$sma$\\sim$bsma}", 
                                            "6"="\\textipa{sa$\\sim$bsa$\\sim$lbsa}",
                                            "7"="\\textipa{za$\\sim$bza$\\sim$dbza}", 
                                            "8"="\\textipa{la$\\sim$mla$\\sim$gmla}", 
                                            "9"="\\textipa{na$\\sim$bna$\\sim$Zbna}" ))

print(xtable(acc), include.rownames = F, sanitize.text.function = identity)

