# ----------------
# Descriptives
# ----------------
library(plyr)
library(ggplot2)
library(latex2exp)
library(extrafont)
library(tidyverse)

results<- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>%
# Remove a few columns to make this easier understandable
  select(file, subject, interval_type, cluster, triplet, repl, AccOff_V) %>%
  filter(subject %in% c(1:4), # which subjects
         cluster %in% c("CV", "CCV", "CCCV"), # which clusters
         interval_type != "LE2A"
  ) 


# Create Plots for descriptive data
ipa <- c('\u{0283}', '\u{0292}')

sh<- paste(ipa[1],"a~m", sep = "")
sh1 <- paste(ipa[1],"a~km", sep = "")
sh2 <- paste(ipa[1], "a", sep="")

sh<- paste(sh,sh1,sep ="")
sh<- paste(sh,sh2,sep="")

dg <- paste(ipa[2],"bna",sep="")
dg <-paste("na~bna~",dg, sep="")

results$triplet <- as.factor(results$triplet)
results$triplet <- revalue(results$triplet, c("1"= "ba~dba~kdba", "2"= sh,"3"="ga~bga~nbga", "4"="ka~ska~mska","5"="ma~sma~bsma", "6"="sa~bsa~lbsa","7"="za~bza~dbza", "8"="la~mla~gmla", "9"=dg ))

results$cluster <- factor(results$cluster, levels = c("CV", "CCV", "CCCV"))
results$interval_type <- factor(results$interval_type, levels = c("CC2A", "RE2A"))

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
#    value[value=="LE2A"] <- "LE-ᴛᴏ-A"
    value[value=="CC2A"] <- "Global timing"#"CC-ᴛᴏ-A"
    value[value=="RE2A"] <- "Local timing" #"RE-ᴛᴏ-A"
  #  value[value=="LE2A"] <- "LE-TO-A"
   # value[value=="CC2A"] <- "CC-TO-A"
   # value[value=="RE2A"] <- "RE-TO-A"
  }
  return(value)
}


(plot<- ggplot(data = results,
               aes(x = cluster, 
                   y = AccOff_V)))
(plot <- plot + xlab(""))
(plot <- plot + ylab(""))
(plot <- plot + ggtitle("Acoustic anchor\n"))
(plot <- plot + theme_bw())
(plot <- plot + geom_jitter(size=.5, width = .2))
(plot <- plot + facet_grid(triplet ~ interval_type, labeller = i_labeller))

(plot <- plot + theme(panel.grid.major = element_blank()))
(plot <- plot + theme(panel.grid.minor = element_blank()))
plot <- plot + theme(legend.position="none")
#(plot <- plot + scale_y_continuous(breaks=c(100,200,300,400,500)))
(plot <- plot + scale_y_continuous(breaks=seq(100,400,100), limits = c(10,400)))

(plot <- plot + stat_smooth(method="lm", se=F, aes(group=1,colour="red"),size=1) + guides(colour=FALSE))
(plot <- plot + theme(
  plot.title = element_text( face="bold", size=16, hjust=0),
  axis.ticks.y = element_blank(), 
  axis.text.y =element_blank(),
  axis.text.x =element_text(size=15),
  axis.title=element_text(vjust=0.8, size = 17),
  strip.text.x = element_text(face="bold", size = 12),
  strip.text.y = element_text(face="italic", size = 12),#, angle = 360),
  strip.background = element_rect( fill = "transparent")))

(plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                      plot.background = element_rect(fill = "transparent",colour = NA)))

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/raw_acc.pdf", family="Times", bg = "transparent", width = 5, height = 13)
plot
dev.off()

