library(tidyr)
library(dplyr)
library(plyr)
library(ggplot2)
library(lmerTest)
source("functions/style3.R")

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
    value[value=="CC2A"] <- "Global timing"# "CC-ᴛᴏ-A"
    value[value=="RE2A"] <- "Local timing" #"RE-ᴛᴏ-A"
  }
  return(value)
}

results <- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>% filter(interval_type != "LE2A")
results$interval_type <- factor(results$interval_type, ordered = TRUE, levels = c( "CC2A", "RE2A"))
results$cluster <- factor(results$cluster, ordered = TRUE, levels = c("CV", "CCV", "CCCV"))


results$sonority <- 0
results[results$triplet == 1,]$sonority <- 111 
results[results$triplet == 2,]$sonority <- 132
results[results$triplet == 3,]$sonority <- 311
results[results$triplet == 4,]$sonority <- 321  
results[results$triplet == 5,]$sonority <- 123
results[results$triplet == 6,]$sonority <- 412
results[results$triplet == 7,]$sonority <- 112
results[results$triplet == 8,]$sonority <- 134
results[results$triplet == 9,]$sonority <- 213

results$sonority <- as.character(results$sonority)

results[results$cluster == "CV",]$sonority <- substr(results[results$cluster == "CV",]$sonority, start = 3, stop = 3)
results[results$cluster == "CCV",]$sonority <- substr(results[results$cluster == "CCV",]$sonority, start = 2, stop = 2)
results[results$cluster == "CCCV",]$sonority <- substr(results[results$cluster == "CCCV",]$sonority, start = 1, stop = 1)

results$profile <- NA

for(i in unique(results$triplet)){
  triplet <- results %>% filter(triplet == i)
  CV <- unique(triplet[triplet$cluster == "CV",]$sonority)
  CCV <- unique(triplet[triplet$cluster == "CCV",]$sonority)
  CCCV <- unique(triplet[triplet$cluster == "CCCV",]$sonority)
  
  CCCV_CCV <- ifelse(CCCV > CCV, "falling",
                     ifelse(CCCV < CCV, "rising", 
                          ifelse(CCCV == CCV, "level", NA)))

  CCV_CV <- ifelse(CCV > CV, "falling",
                  ifelse(CCV < CV, "rising", 
                        ifelse(CCV == CV, "level", NA)))
  
  results[results$triplet == i ,]$profile <- paste(CCCV_CCV, CCV_CV, sep = "~")
}
 
table(results$profile, results$cluster)

plot <- ggplot(data = results, aes(x = cluster, y = froP_V )) +
  geom_boxplot() 
plot <- plot + facet_grid(profile ~ interval_type, labeller = i_labeller)
plot <- style(plot);plot

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/risefalllevelson.pdf", family="Times", bg = "transparent", width = 5, height = 7)
plot
dev.off()



