# 1. Enter sonority profile as a factor. 
library(tidyr)
library(dplyr)
library(ggplot2)
source("functions/style.R")

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
    value[value=="CC2A"] <- "Global timing"# "CC-ᴛᴏ-A"
    value[value=="RE2A"] <- "Local timing" #"RE-ᴛᴏ-A"
  }
  return(value)
}

results <- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>% filter(interval_type != "LE2A")
results$interval_type <- factor(results$interval_type, ordered = TRUE, levels = c("CC2A", "RE2A"))
results$cluster <- factor(results$cluster, ordered = TRUE, levels = c("CV", "CCV", "CCCV"))

results$sonority <- 0
results[results$triplet == 1,]$sonority <- 111 
results[results$triplet == 2,]$sonority <- 132
results[results$triplet == 3,]$sonority <- 311
results[results$triplet == 4,]$sonority <- 321  
results[results$triplet == 5,]$sonority <- 123
results[results$triplet == 6,]$sonority <- 412
results[results$triplet == 7,]$sonority <- 112
results[results$triplet == 8,]$sonority <- 134
results[results$triplet == 9,]$sonority <- 213

ipa <- c('\u{0283}', '\u{0292}')

sh<- paste(ipa[1],"a~m", sep = "")
sh1 <- paste(ipa[1],"a~km", sep = "")
sh2 <- paste(ipa[1], "a", sep="")

sh<- paste(sh,sh1,sep ="")
sh<- paste(sh,sh2,sep="")

dg <- paste(ipa[2],"bna",sep="")
dg<-paste("na~bna~",dg, sep="")

results$triplet <- as.character(results$triplet)
results$triplet <- revalue(results$triplet, c("1"= "ba~dba~kdba", "2"= sh,"3"="ga~bga~nbga", "4"="ka~ska~mska","5"="ma~sma~bsma", "6"="sa~bsa~lbsa","7"="za~bza~dbza", "8"="la~mla~gmla", "9"=dg ))
results$triplet <- paste(results$sonority, results$triplet, sep = ":\n")

plot <- ggplot(data = results, aes(x = cluster, y = froP_V )) +
  geom_boxplot() 
plot <- plot + facet_grid(triplet ~ interval_type, labeller = i_labeller)
plot <- plot + xlab("")
plot <- plot + ylab("Interval duration (ms)");plot
plot <- style(plot)
plot

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/sonority_fro.pdf", family="Times", bg = "transparent", width = 5, height = 7)
plot
dev.off()


(summary <- results %>% dplyr::group_by( sonority, interval_type, subject) %>%
    dplyr::summarise(M = mean(AccOff_V),
              SD = sd(AccOff_V),
              RSD = sd(AccOff_V)/mean(AccOff_V)))

ggplot(data = summary, aes(x = sonority, y = RSD ), 
       color = interval_type) +
  geom_boxplot() +
  facet_grid(subject ~ interval_type)
